<?php

namespace common\logic\Distribution\Distribution\Service;

use common\logic\AbstractGenerator;
use common\logic\Distribution\Distribution\Model\Distribution;
use common\logic\Order\Order\Repository\OrderRepository;
use kartik\mpdf\Pdf;

class DistributionShoppingCartLabelsPdfGenerator extends AbstractGenerator
{
    protected OrderRepository $orderRepository;

    public function loadDependencies(): void
    {
        $this->orderRepository = $this->loadService(OrderRepository::class);
    }

    public function generateDistributionShoppingCartLabelsPdf(Distribution $distribution)
    {
        $ordersArray = $this->orderRepository->findOrdersByDistribution($distribution);

        $content = \Yii::$app->getView()->render('@backend/views/distribution/shopping-cart-labels.php', [
            'distribution' => $distribution,
            'ordersArray' => $ordersArray,
        ]);

        $pdf = new Pdf([
            'mode' => Pdf::MODE_UTF8,
            'format' => Pdf::FORMAT_A4,
            'orientation' => Pdf::ORIENT_PORTRAIT,
            'destination' => Pdf::DEST_BROWSER,
            'filename' => \Yii::getAlias(
                '@app/web/pdf/Etiquettes-' . $distribution->date . '-' . $this->getProducerContextId() . '.pdf'
            ),
            'content' => $content,
            'cssInline' => $this->getCss(),
            'methods' => [
                'SetHeader' => ['Étiquettes du ' . date('d/m/Y', strtotime($distribution->date))],
                'SetFooter' => ['{PAGENO}'],
            ]
        ]);

        return $pdf->render();
    }

    public function getCss(): string
    {
        return '
            @page {
              margin: 0px 0px 0px 0px !important;
              padding: 0px 0px 0px 0px !important;
            }
            
            body {
              font-family: Arial, Helvetica, sans-serif;
              font-size: 13px;
            }
            
            .clr {
              clear: both;
            }
            
            .shopping-cart-label {
              box-sizing: border-box;
              width: 49.9%;
              height: 368px;
              float: left;
              text-align: center;
            }
            
            .shopping-cart-label.shopping-cart-label-0,
            .shopping-cart-label.shopping-cart-label-2 {
              border-bottom: solid 1px #e0e0e0;
              border-right: solid 1px #e0e0e0;
            }
            
            .shopping-cart-label.shopping-cart-label-1,
            .shopping-cart-label.shopping-cart-label-3 {
              border-bottom: solid 1px #e0e0e0;
            }
            
            .shopping-cart-label.shopping-cart-label-4 {
                border-right: solid 1px #e0e0e0;
            }
            
            .shopping-cart-label .inner {
                   padding: 20px;
            }
            
            .shopping-cart-label .username {
                margin-bottom: 3px;
                font-weight: bold;
                font-size: 18px;
            }
            
            .shopping-cart-label .point-sale {
                margin-bottom: 10px;
                font-size: 15px;
                text-transform: uppercase;
            }
            
            .shopping-cart-label .products {
                   
            }
                    ';
    }
}